-- vim: ts=4 sw=4 ai et

-- We need to have the localization table set up before this file is loaded.
local L = Ammo.strings

local function mkchatoption (ord, disf)
    local t = {
        type = 'toggle',
        name = L["Chat"],
        desc = L["Provide warning in the default chat window."],
        order = ord,
        disabled = disf,
    }
    return t
end

local function mkwarnoption (ord, disf)
    local t = {
        type = 'toggle',
        name = L["Error frame"],
        desc = L["Provide warning in the standard error frame (top center of screen)."],
        order = ord,
        disabled = disf,
    }
    return t
end

local function mkvoiceoption (ord, disf)
    local t = {
        type = 'toggle',
        name = L["Voice"],
        desc = L["Provide vocal warning."],
        disabled = disf,
        order = ord,
    }
    return t
end

local function fcl ()
    return not Ammo.db.profile.current_low_enabled
end

local function fce ()
    return not Ammo.db.profile.current_exhausted_enabled
end

local function fae ()
    return not Ammo.db.profile.all_exhausted_enabled
end

local ammotable = {
    premium = L["Premium"],
    lowgrade = L["Low-grade"]
}

local function glue_ammo_types_available ()
    local links = Ammo.addon:AvailableAmmoTypes ()
    local table = {}
    for _, link in ipairs (links) do
        table[link] = link
    end
    -- Ensure we list the currently selected ammo type, even if we don't have any of it
    local ptype = Ammo.db.profile.restock_premium_type
    local ltype = Ammo.db.profile.restock_lowgrade_type
    if ptype and not table[ptype] then table[ptype] = ptype end
    if ltype and not table[ltype] then table[ltype] = ltype end
    return table
end

Ammo.cfghandler = {}

Ammo.config = {
    type = 'group',
    handler = Ammo.cfghandler,
    get = "GetVal", set = "SetVal",
    args = {
        general = {
            type = 'group',
            name = L["General settings"],
            args = {
                blurb = {
                    type = 'description',
                    order = 1,
                    name = L["Ammo-matique provides automated ammo handling - it can automatically reload for you if you run out of your current ammo type, and it can automatically select the suitable ammo type for any particular situation."],
                },
                blurb2 = {
                    type = 'description',
                    order = 2,
                    name = L["Ammo-matique uses two terms when referring to ammo - 'premium' and 'lowgrade'. Premium refers to the ammo type with the highest DPS that you have available. Conversely, lowgrade refers to the ammo type with the lowest DPS."],
                },
                blurb3 = {
                    type = 'description',
                    order = 3,
                    name = L["Tip: you can use /ammo to access Ammo-matique functionality from macros or the chat box."],
                },
                hdr = {
                    type = 'header',
                    name = "",
                    order = 19,
                },
                reload = {
                    type = 'toggle',
                    name = L["Auto-reload"],
                    desc = L["Automatically reload when current ammo is exhausted."],
                    order = 20,
                },
                switch = {
                    type = 'toggle',
                    name = L["Auto-switch"],
                    desc = L["Automatically switch ammo in PvE and/or PvP."],
                    order = 30,
                },
                notify = {
                    type = 'toggle',
                    name = L["Notifications"],
                    desc = L["Provide status notifications, e.g. when switching ammo, or (de)activating auto-reload."],
                    order = 40,
                },
                spacer = {
                    type = 'description',
                    order = 99,
                    name = "\n\n\n\n\n\n\n",
                },
                hdr2 = {
                    type = 'header',
                    name = "",
                    order = 100,
                },
                author = {
                    type = 'description',
                    name = "By Anyia of Horde Yakka (Jubei'Thos)\n",
                    order = 101,
                },
            }
        },
        warnings = {
            type = 'group',
            name = L["Ammo warnings"],
            args = {
                blurb = {
                    type = 'description',
                    order = 1,
                    name = L["Ammo-matique can provide warnings when you are running low or out of ammunition in a variety of ways. Select the ones you would like."],
                },
                voiceset = {
                    type = 'select',
                    order = 5,
                    name = L["Voice set"],
                    desc = L["Voice set to use if voice warnings are enabled."],
                    values = { male1 = L["Male"], female1 = L["Female"] },
                },
                current_low = {
                    type = 'group',
                    inline = true,
                    name = L["Low ammo warning"],
                    order = 10,
                    args = {
                        enabled = {
                            type = 'toggle',
                            name = L["Enabled"],
                            desc = L["Warn when the current ammo is running low."],
                            order = 10,
                        },
                        threshold = {
                            type = 'range',
                            name = L["Low ammo threshold"],
                            desc = L["Warn when current ammo falls below this value."],
                            order = 20,
                            min = 0, max = 2000, step = 20,
                            disabled = fcl,
                        },
                        ignoreme = {
                            type = 'description',
                            name = "",
                            order = 29,
                        },
                        text = mkchatoption (30, fcl),
                        warn = mkwarnoption (35, fcl),
                        voice = mkvoiceoption (40, fcl),
                    },
                }, -- End: Low ammo warning
                current_exhausted = {
                    type = 'group',
                    inline = true,
                    name = L["Ammo exhausted warning"],
                    order = 20,
                    args = {
                        enabled = {
                            type = 'toggle',
                            name = L["Enabled"],
                            desc = L["Warn when the current ammo is exhausted."],
                            order = 10,
                        },
                        ignoreme = {
                            type = 'description',
                            name = "",
                            order = 29,
                        },
                        text = mkchatoption (30, fce),
                        warn = mkwarnoption (35, fce),
                        voice = mkvoiceoption (40, fce),
                    },
                }, -- End current_exhausted
                all_exhausted = {
                    type = 'group',
                    inline = true,
                    name = L["All ammo exhausted warning"],
                    order = 30,
                    args = {
                        enabled = {
                            type = 'toggle',
                            name = L["Enabled"],
                            desc = L["Warn when all ammo is exhausted."],
                            order = 10,
                        },
                        ignoreme = {
                            type = 'description',
                            name = "",
                            order = 29,
                        },
                        text = mkchatoption (30, fae),
                        warn = mkwarnoption (35, fae),
                        voice = mkvoiceoption (40, fae),
                    },
                }, -- End all_exhausted
            }
        },
        pve = {
            type = 'group',
            name = L["PvE ammo switching"],
            childGroups = 'tab',
            args = {
                blurb = {
                    type = 'description',
                    order = 1,
                    name = L["Ammo-matique allows you to switch ammo depending on the type of mob you are fighting.\n\nNote: Once premium ammo has been switched in for a fight, it will stay equipped throughout the fight."],
                },

                world = {
                    type = 'group',
                    name = L["World"],
                    order = 10,
                    args = {
                        blurb = {
                            type = 'description',
                            order = 1,
                            name = L["Mobs roaming the world outside any instances."],
                        },
                        bosses = {
                            disabled = function () return not Ammo.db.profile.general_switch end,
                            type = 'group',
                            inline = true,
                            name = L["Bosses"],
                            order = 10,
                            args = {
                                enabled = {
                                    type = 'toggle',
                                    name = L["Enabled"],
                                    desc = L["Switch ammo for bosses."],
                                    order = 10,
                                },
                                ammotype = {
                                    type = 'select',
                                    name = L["Ammo type"],
                                    desc = L["Ammo type to use when fighting bosses."],
                                    order = 20,
                                    disabled = function () return not Ammo.db.profile.bosses_enabled or not Ammo.db.profile.general_switch end,
                                    values = ammotable,
                                }
                            },
                        },
                        elites = {
                            disabled = function () return not Ammo.db.profile.general_switch end,
                            type = 'group',
                            inline = true,
                            name = L["Elites"],
                            order = 20,
                            args = {
                                enabled = {
                                    type = 'toggle',
                                    name = L["Enabled"],
                                    desc = L["Switch ammo for elite mobs."],
                                    order = 10,
                                },
                                ammotype = {
                                    type = 'select',
                                    name = L["Ammo type"],
                                    desc = L["Ammo type to use when fighting elite mobs."],
                                    order = 20,
                                    disabled = function () return not Ammo.db.profile.elites_enabled or not Ammo.db.profile.general_switch end,
                                    values = ammotable,
                                }
                            },
                        },
                        nonelites = {
                            disabled = function () return not Ammo.db.profile.general_switch end,
                            type = 'group',
                            inline = true,
                            name = L["Non-elites"],
                            order = 30,
                            args = {
                                enabled = {
                                    type = 'toggle',
                                    name = L["Enabled"],
                                    desc = L["Switch ammo for non-elite mobs."],
                                    order = 10,
                                },
                                ammotype = {
                                    type = 'select',
                                    name = L["Ammo type"],
                                    desc = L["Ammo type to use when fighting non-elite mobs."],
                                    order = 20,
                                    disabled = function () return not Ammo.db.profile.nonelites_enabled or not Ammo.db.profile.general_switch end,
                                    values = ammotable,
                                },
                            },
                        },
                    },
                }, -- end World tab

                instance = {
                    type = 'group',
                    name = L["Instance"],
                    order = 20,
                    args = {
                        blurb = {
                            type = 'description',
                            order = 1,
                            name = L["Mobs inside regular instances."],
                        },
                        instance_bosses = {
                            disabled = function () return not Ammo.db.profile.general_switch end,
                            type = 'group',
                            inline = true,
                            name = L["Bosses"],
                            order = 10,
                            args = {
                                enabled = {
                                    type = 'toggle',
                                    name = L["Enabled"],
                                    desc = L["Switch ammo for bosses."],
                                    order = 10,
                                },
                                ammotype = {
                                    type = 'select',
                                    name = L["Ammo type"],
                                    desc = L["Ammo type to use when fighting bosses."],
                                    order = 20,
                                    disabled = function () return not Ammo.db.profile.instance_bosses_enabled or not Ammo.db.profile.general_switch end,
                                    values = ammotable,
                                }
                            },
                        },
                        instance_elites = {
                            disabled = function () return not Ammo.db.profile.general_switch end,
                            type = 'group',
                            inline = true,
                            name = L["Elites"],
                            order = 20,
                            args = {
                                enabled = {
                                    type = 'toggle',
                                    name = L["Enabled"],
                                    desc = L["Switch ammo for elite mobs."],
                                    order = 10,
                                },
                                ammotype = {
                                    type = 'select',
                                    name = L["Ammo type"],
                                    desc = L["Ammo type to use when fighting elite mobs."],
                                    order = 20,
                                    disabled = function () return not Ammo.db.profile.instance_elites_enabled or not Ammo.db.profile.general_switch end,
                                    values = ammotable,
                                }
                            },
                        },
                        instance_nonelites = {
                            disabled = function () return not Ammo.db.profile.general_switch end,
                            type = 'group',
                            inline = true,
                            name = L["Non-elites"],
                            order = 30,
                            args = {
                                enabled = {
                                    type = 'toggle',
                                    name = L["Enabled"],
                                    desc = L["Switch ammo for non-elite mobs."],
                                    order = 10,
                                },
                                ammotype = {
                                    type = 'select',
                                    name = L["Ammo type"],
                                    desc = L["Ammo type to use when fighting non-elite mobs."],
                                    order = 20,
                                    disabled = function () return not Ammo.db.profile.instance_nonelites_enabled or not Ammo.db.profile.general_switch end,
                                    values = ammotable,
                                },
                            },
                        },
                    },
                }, -- end Instance tab

                hinstance = {
                    type = 'group',
                    name = L["Heroic Instance"],
                    order = 30,
                    args = {
                        blurb = {
                            type = 'description',
                            order = 1,
                            name = L["Mobs inside heroic instances."],
                        },
                        hinstance_bosses = {
                            disabled = function () return not Ammo.db.profile.general_switch end,
                            type = 'group',
                            inline = true,
                            name = L["Bosses"],
                            order = 10,
                            args = {
                                enabled = {
                                    type = 'toggle',
                                    name = L["Enabled"],
                                    desc = L["Switch ammo for bosses."],
                                    order = 10,
                                },
                                ammotype = {
                                    type = 'select',
                                    name = L["Ammo type"],
                                    desc = L["Ammo type to use when fighting bosses."],
                                    order = 20,
                                    disabled = function () return not Ammo.db.profile.hinstance_bosses_enabled or not Ammo.db.profile.general_switch end,
                                    values = ammotable,
                                }
                            },
                        },
                        hinstance_elites = {
                            disabled = function () return not Ammo.db.profile.general_switch end,
                            type = 'group',
                            inline = true,
                            name = L["Elites"],
                            order = 20,
                            args = {
                                enabled = {
                                    type = 'toggle',
                                    name = L["Enabled"],
                                    desc = L["Switch ammo for elite mobs."],
                                    order = 10,
                                },
                                ammotype = {
                                    type = 'select',
                                    name = L["Ammo type"],
                                    desc = L["Ammo type to use when fighting elite mobs."],
                                    order = 20,
                                    disabled = function () return not Ammo.db.profile.hinstance_elites_enabled or not Ammo.db.profile.general_switch end,
                                    values = ammotable,
                                }
                            },
                        },
                        hinstance_nonelites = {
                            disabled = function () return not Ammo.db.profile.general_switch end,
                            type = 'group',
                            inline = true,
                            name = L["Non-elites"],
                            order = 30,
                            args = {
                                enabled = {
                                    type = 'toggle',
                                    name = L["Enabled"],
                                    desc = L["Switch ammo for non-elite mobs."],
                                    order = 10,
                                },
                                ammotype = {
                                    type = 'select',
                                    name = L["Ammo type"],
                                    desc = L["Ammo type to use when fighting non-elite mobs."],
                                    order = 20,
                                    disabled = function () return not Ammo.db.profile.hinstance_nonelites_enabled or not Ammo.db.profile.general_switch end,
                                    values = ammotable,
                                },
                            },
                        },
                    },
                }, -- end HInstance tab

                raid = {
                    type = 'group',
                    name = L["Raid Instance"],
                    order = 40,
                    args = {
                        blurb = {
                            type = 'description',
                            order = 1,
                            name = L["Mobs inside raid instances."],
                        },
                        raid_bosses = {
                            disabled = function () return not Ammo.db.profile.general_switch end,
                            type = 'group',
                            inline = true,
                            name = L["Bosses"],
                            order = 10,
                            args = {
                                enabled = {
                                    type = 'toggle',
                                    name = L["Enabled"],
                                    desc = L["Switch ammo for bosses."],
                                    order = 10,
                                },
                                ammotype = {
                                    type = 'select',
                                    name = L["Ammo type"],
                                    desc = L["Ammo type to use when fighting bosses."],
                                    order = 20,
                                    disabled = function () return not Ammo.db.profile.raid_bosses_enabled or not Ammo.db.profile.general_switch end,
                                    values = ammotable,
                                }
                            },
                        },
                        raid_elites = {
                            disabled = function () return not Ammo.db.profile.general_switch end,
                            type = 'group',
                            inline = true,
                            name = L["Elites"],
                            order = 20,
                            args = {
                                enabled = {
                                    type = 'toggle',
                                    name = L["Enabled"],
                                    desc = L["Switch ammo for elite mobs."],
                                    order = 10,
                                },
                                ammotype = {
                                    type = 'select',
                                    name = L["Ammo type"],
                                    desc = L["Ammo type to use when fighting elite mobs."],
                                    order = 20,
                                    disabled = function () return not Ammo.db.profile.raid_elites_enabled or not Ammo.db.profile.general_switch end,
                                    values = ammotable,
                                }
                            },
                        },
                        raid_nonelites = {
                            disabled = function () return not Ammo.db.profile.general_switch end,
                            type = 'group',
                            inline = true,
                            name = L["Non-elites"],
                            order = 30,
                            args = {
                                enabled = {
                                    type = 'toggle',
                                    name = L["Enabled"],
                                    desc = L["Switch ammo for non-elite mobs."],
                                    order = 10,
                                },
                                ammotype = {
                                    type = 'select',
                                    name = L["Ammo type"],
                                    desc = L["Ammo type to use when fighting non-elite mobs."],
                                    order = 20,
                                    disabled = function () return not Ammo.db.profile.raid_nonelites_enabled or not Ammo.db.profile.general_switch end,
                                    values = ammotable,
                                },
                            },
                        },
                    },
                }, -- end Raid tab

                hraid = {
                    type = 'group',
                    name = L["Heroic Raid Instance"],
                    order = 50,
                    args = {
                        blurb = {
                            type = 'description',
                            order = 1,
                            name = L["Mobs inside heroic raid instances."],
                        },
                        hraid_bosses = {
                            disabled = function () return not Ammo.db.profile.general_switch end,
                            type = 'group',
                            inline = true,
                            name = L["Bosses"],
                            order = 10,
                            args = {
                                enabled = {
                                    type = 'toggle',
                                    name = L["Enabled"],
                                    desc = L["Switch ammo for bosses."],
                                    order = 10,
                                },
                                ammotype = {
                                    type = 'select',
                                    name = L["Ammo type"],
                                    desc = L["Ammo type to use when fighting bosses."],
                                    order = 20,
                                    disabled = function () return not Ammo.db.profile.hraid_bosses_enabled or not Ammo.db.profile.general_switch end,
                                    values = ammotable,
                                }
                            },
                        },
                        hraid_elites = {
                            disabled = function () return not Ammo.db.profile.general_switch end,
                            type = 'group',
                            inline = true,
                            name = L["Elites"],
                            order = 20,
                            args = {
                                enabled = {
                                    type = 'toggle',
                                    name = L["Enabled"],
                                    desc = L["Switch ammo for elite mobs."],
                                    order = 10,
                                },
                                ammotype = {
                                    type = 'select',
                                    name = L["Ammo type"],
                                    desc = L["Ammo type to use when fighting elite mobs."],
                                    order = 20,
                                    disabled = function () return not Ammo.db.profile.hraid_elites_enabled or not Ammo.db.profile.general_switch end,
                                    values = ammotable,
                                }
                            },
                        },
                        hraid_nonelites = {
                            disabled = function () return not Ammo.db.profile.general_switch end,
                            type = 'group',
                            inline = true,
                            name = L["Non-elites"],
                            order = 30,
                            args = {
                                enabled = {
                                    type = 'toggle',
                                    name = L["Enabled"],
                                    desc = L["Switch ammo for non-elite mobs."],
                                    order = 10,
                                },
                                ammotype = {
                                    type = 'select',
                                    name = L["Ammo type"],
                                    desc = L["Ammo type to use when fighting non-elite mobs."],
                                    order = 20,
                                    disabled = function () return not Ammo.db.profile.hraid_nonelites_enabled or not Ammo.db.profile.general_switch end,
                                    values = ammotable,
                                },
                            },
                        },
                    },
                }, -- end HRaid tab

            },
        },
        pvp = {
            type = 'group',
            name = L["PvP ammo switching"],
            disabled = function () return not Ammo.db.profile.general_switch end,
            args = {
                blurb = {
                    type = 'description',
                    order = 1,
                    name = L["Whenever you engage (or prepare to engage) another player in combat, Ammo-matique can automatically switch in ammo for you based on the situation."],
                },
                arena = {
                    type = 'group',
                    inline = true,
                    name = L["Arena"],
                    order = 10,
                    args = {
                        enabled = {
                            type = 'toggle',
                            name = L["Enabled"],
                            desc = L["Switch ammo when engaging in an Arena."],
                            order = 10,
                        },
                        ammotype = {
                            type = 'select',
                            name = L["Ammo type"],
                            desc = L["Ammo type to use when engaging in an Arena."],
                            order = 20,
                            disabled = function () return not Ammo.db.profile.arena_enabled or not Ammo.db.profile.general_switch end,
                            values = ammotable,
                        },
                    },
                },
                bg = {
                    type = 'group',
                    inline = true,
                    name = L["Battlegrounds"],
                    order = 20,
                    args = {
                        enabled = {
                            type = 'toggle',
                            name = L["Enabled"],
                            desc = L["Switch ammo when engaging in Battlegrounds."],
                            order = 10,
                        },
                        ammotype = {
                            type = 'select',
                            name = L["Ammo type"],
                            desc = L["Ammo type to use when engaging in Battlegrounds."],
                            order = 20,
                            disabled = function () return not Ammo.db.profile.bg_enabled or not Ammo.db.profile.general_switch end,
                            values = ammotable,
                        },
                    },
                },
                world = {
                    type = 'group',
                    inline = true,
                    name = L["World PvP"],
                    order = 30,
                    args = {
                        enabled = {
                            type = 'toggle',
                            name = L["Enabled"],
                            desc = L["Switch ammo when engaging in world PvP."],
                            order = 10,
                        },
                        ammotype = {
                            type = 'select',
                            name = L["Ammo type"],
                            desc = L["Ammo type to use when engaging in world PvP."],
                            order = 20,
                            disabled = function () return not Ammo.db.profile.world_enabled or not Ammo.db.profile.general_switch end,
                            values = ammotable,
                        },
                    },
                },
            }
        }, -- end pvp section

        restock = {
            type = 'group',
            name = L["Ammo restocking (experimental)"],
            args = {
                blurb = {
                    type = 'description',
                    order = 1,
                    name = L["Ammo-matique can automatically restock your ammo supply whenever you visit a vendor selling ammo.\nWARNING: This feature is experimental at this stage, and may cost you lots of gold!"],
                },
                premium = {
                    type = 'toggle',
                    order = 10,
                    name = L["Restock premium"],
                    desc = L["Restock premium ammo automatically when visiting an ammo vendor."]
                },
                restock_premium = {
                    type = 'group',
                    inline = true,
                    name = L["Restock options"],
                    order = 11,
                    disabled = function () return not Ammo.db.profile.restock_premium end,
                    args = {
                        count = {
                            type = 'range',
                            order = 10,
                            min = 0, max = 20000, step = 1, bigStep = 200,
                            name = L["Ammo stock level"],
                            desc = L["Ammo stock level to adhere to (individual arrows/bullets, not stacks)"],
                        },
                        spacer = { type = 'description', order = 11, name = "" },
                        fixed = {
                            type = 'toggle',
                            order = 20,
                            name = L["Set ammo type"],
                            desc = L["Always buy the specified ammo type for premium ammo (as opposed to automatically discovering it)"],
                        },
                        type = {
                            type = 'select',
                            order = 30,
                            disabled = function () return not Ammo.db.profile.restock_premium or not Ammo.db.profile.restock_premium_fixed end,
                            name = L["Ammo type"],
                            desc = L["Always buy this ammo type when restocking. If the desired ammo type is not listed, please purchase a sample of it and come back here."],
                            values = glue_ammo_types_available,
                        },
                    },
                },
                lowgrade = {
                    type = 'toggle',
                    order = 100,
                    name = L["Restock low-grade"],
                    desc = L["Restock low-grade ammo automatically when visiting an ammo vendor."]
                },
                restock_lowgrade = {
                    type = 'group',
                    inline = true,
                    name = L["Restock options"],
                    order = 101,
                    disabled = function () return not Ammo.db.profile.restock_lowgrade end,
                    args = {
                        count = {
                            type = 'range',
                            order = 10,
                            min = 0, max = 20000, step = 1, bigStep = 200,
                            name = L["Ammo stock level"],
                            desc = L["Ammo stock level to adhere to (individual arrows/bullets, not stacks)"],
                        },
                        spacer = { type = 'description', order = 11, name = "" },
                        fixed = {
                            type = 'toggle',
                            order = 20,
                            name = L["Set ammo type"],
                            desc = L["Always buy the specified ammo type for low-grade ammo (as opposed to automatically discovering it)"],
                        },
                        type = {
                            type = 'select',
                            order = 30,
                            disabled = function () return not Ammo.db.profile.restock_lowgrade or not Ammo.db.profile.restock_lowgrade_fixed end,
                            name = L["Ammo type"],
                            desc = L["Always buy this ammo type when restocking. If the desired ammo type is not listed, please purchase a sample of it and come back here."],
                            values = glue_ammo_types_available,
                        },
                    },
                },
            },
        }, -- end restock section

    }
}

Ammo.defaults = {
    profile = {
        general_reload = true,
        general_switch = true,
        general_notify = true,
        warnings_voiceset = "female1",
        current_low_enabled = true,
        current_low_threshold = 400,
        current_low_text = true,
        current_low_warn = false,
        current_low_voice = true,
        current_exhausted_enabled = true,
        current_exhausted_text = true,
        current_exhausted_warn = false,
        current_exhausted_voice = true,
        all_exhausted_enabled = true,
        all_exhausted_text = true,
        all_exhausted_warn = false,
        all_exhausted_voice = true,
        bosses_enabled = true,
        bosses_ammotype = "premium",
        instance_bosses_enabled = true,
        instance_bosses_ammotype = "lowgrade",
        hinstance_bosses_enabled = true,
        hinstance_bosses_ammotype = "premium",
        raid_bosses_enabled = true,
        raid_bosses_ammotype = "premium",
        hraid_bosses_enabled = true,
        hraid_bosses_ammotype = "premium",
        elites_enabled = true,
        elites_ammotype = "lowgrade",
        instance_elites_enabled = true,
        instance_elites_ammotype = "lowgrade",
        hinstance_elites_enabled = true,
        hinstance_elites_ammotype = "lowgrade",
        raid_elites_enabled = true,
        raid_elites_ammotype = "lowgrade",
        hraid_elites_enabled = true,
        hraid_elites_ammotype = "lowgrade",
        nonelites_enabled = true,
        nonelites_ammotype = "lowgrade",
        instance_nonelites_enabled = true,
        instance_nonelites_ammotype = "lowgrade",
        hinstance_nonelites_enabled = true,
        hinstance_nonelites_ammotype = "lowgrade",
        raid_nonelites_enabled = true,
        raid_nonelites_ammotype = "lowgrade",
        hraid_nonelites_enabled = true,
        hraid_nonelites_ammotype = "lowgrade",
        arena_enabled = true,
        arena_ammotype = "premium",
        bg_enabled = false,
        bg_ammotype = "lowgrade",
        world_enabled = false,
        world_ammotype = "lowgrade",

        -- Restock settings
        restock_premium = false,
        restock_premium_count = 0,
        restock_premium_fixed = false,
        restock_premium_type = nil,
        restock_lowgrade = false,
        restock_lowgrade_count = 1000,
        restock_lowgrade_fixed = false,
        restock_lowgrade_type = nil,
    }
}

-- Map to get config var prefix.
-- Ammo.pvemap[instance_type][difficulty][unittype]
Ammo.pvemap = {
    none = {
      [1] = {
        worldboss = "bosses",
        elite = "elites",
        normal = "nonelites"
      },
      [2] = {
        worldboss = "bosses",
        elite = "elites",
        normal = "nonelites"
      }
    },
    party = {
      [1] = {
        worldboss = "instance_bosses",
        elite = "instance_elites",
        normal = "instance_nonelites"
      },
      [2] = {
        worldboss = "hinstance_bosses",
        elite = "hinstance_elites",
        normal = "hinstance_nonelites"
      }
    },
    raid = {
      [1] = {
        worldboss = "raid_bosses",
        elite = "raid_elites",
        normal = "raid_nonelites"
      },
      [2] = {
        worldboss = "hraid_bosses",
        elite = "hraid_elites",
        normal = "hraid_nonelites"
      }
    }
}

function Ammo.cfghandler:GetVal (info)
    local varname = info[#info -1].."_"..info[#info]
    return Ammo.db.profile[varname]
end

function Ammo.cfghandler:SetVal (info, v)
    local varname = info[#info -1].."_"..info[#info]
    Ammo.db.profile[varname] = v
end

